@@ -10,17 +10,15 @@ from typing import Any
 class CustomJSONEncoder(json.JSONEncoder):
     def default(self, o) -> Any:
         try:
-            return super(CustomJSONEncoder, self).default(o)
+            return super().default(o)
         except TypeError:
-            if isinstance(o, datetime):
+            if isinstance(o, (datetime, date)):
                 return o.isoformat()
-            elif isinstance(o, date):
-                return o.isoformat()
-            elif isinstance(o, bytes):
+            if isinstance(o, bytes):
                 return base64.b64encode(o).decode('ascii')
-            elif dataclasses.is_dataclass(o):
+            if dataclasses.is_dataclass(o):
                 return dataclasses.asdict(o)
-            elif isinstance(o, (Decimal, socket, type, Exception)):
+            if isinstance(o, (Decimal, socket, type, Exception)):
                 return str(o)
 
         return type(o).__name__
